<?php



require_once 'config.php';
require_once GREEN_ZONE_DIR . 'Forms/GZ_BaseForm.php';
require_once 'Classes/Interfaces/ObsSetMapper.php';
require_once 'Classes/Model/ObservationSet.php';



class ViewProfilesAndCalsForm extends GZ_BaseForm
{
  public function __construct( $s_gz )
  {
    parent::__construct( $s_gz );
    
    $this->data_set = null;
    
    $this->last_result = Array();
    
    $this->LoadSessionData();
  }
  
  public function ReadForm()
  {
    $obs_table = new GZ_Table( $this->gz, 'tabQueryResults' );
    $obs_table->ReadForm();
    $this->selected_ids = $obs_table->GetSelectedIDs();
    
    $this->data_set = Array();
    foreach( $this->last_result as $next_obs_set )
      if( in_array( $next_obs_set->GetObservation()->GetFileID(), $this->selected_ids ) )
	$this->data_set[] = $next_obs_set;
    
    $this->ProducePlots();
  }
  
  public function ProcessActions()
  {
  }
  
  public function Display()
  {
    $smarty = $this->gz->CreateSmarty();
    
    $data_mapper = new ObsSetMapper();
    
    $this->gz->smarty_assign( $smarty, 'data_mapper', $data_mapper );
    $this->gz->smarty_assign( $smarty, 'data_set', $this->data_set );
    
    $smarty->Display( 'ViewProfilesAndCalsForm.tpl' );
  }
  
  public function GetDataSet() { return $this->data_set; }
  
  private $selected_ids;
  private $data_set;
  private $last_results;
  
  private function LoadSessionData()
  {
    global $_SESSION;
    
    if( isset( $_SESSION['last_results'] ) )
      $this->last_result = $_SESSION['last_results'];
  }
  
  //! This function calls pav to create the plots for the observations we want to see
  private function ProducePlots()
  {
    foreach( $this->data_set as $next_obs_set )
    {
      $next_id = $next_obs_set->GetObservation()->GetFileID();
      
      $plot_dir = Dir::ConvertPathString( WEB_ROOT . '/plots' );
      if( !$plot_dir->Exists() )
	throw new GZ_Exception( 'plot directory does not exists ' . $plot_dir->GetPath(), 'ViewProfilesForm::ProducePlots' );
      
      $obs_plot = File::ConvertFullPath( $plot_dir->GetPath() . "O$next_id.png" );
      if( !$obs_plot->Exists() )
      {
        $this->MakePlot( $plot_dir, $next_id, $next_obs_set->GetObservation()->GetFile() );
        
        foreach( $next_obs_set->GetCalibrations() as $next_cal )
        {
          $this->MakePlot( $plot_dir, $next_cal->GetFileID(), $next_cal->GetFile(), true );
        }
      }
    }
  }
  
  //! This function produces a plot given the source filename, the target directory and an id for the plot
  private function MakePlot( Dir $plot_dir, $plot_id, File $src_file, $is_calibration = false )
  {
    $target_plot_file = File::ConvertFullPath( $plot_dir->GetPath() . '/' . $src_file->GetFilename() );
    
    if( !$target_plot_file->Exists() )
    {
      $cwd = getcwd();
      chdir( $plot_dir->GetPath() );
      
      $pav_cmd = FIX_LD_LIB . PAV_CMD . ' -DCTFpg ';
      if($is_calibration )
        $pav_cmd .= 'C';
      else
        $pav_cmd .= 'O';
      
      $pav_cmd .= "$plot_id.png/png ";
      $pav_cmd .= $src_file->GetFullPath();
      
      $retval = 0;
      $all_lines = Array();
      exec( $pav_cmd );
      
      if( $retval != 0 )
        throw new GZ_Exception( 'Pav call failed ' . $pav_cmd, 'ViewProfilesForm::MakePlot' );
      
      chdir( $cwd );
    }
  }
};

?>